/* ISC license. */

/* Generated by: ./configure --prefix=/usr --sysconfdir=/etc --disable-allstatic --disable-static --enable-pkgconfig --enable-shared --with-pkgconfig */

#ifndef TIPIDEE_CONFIG_H
#define TIPIDEE_CONFIG_H

#define TIPIDEE_VERSION "0.0.7.2"
#define TIPIDEE_BINPREFIX ""
#define TIPIDEE_EXTBINPREFIX ""
#define TIPIDEE_EXTLIBEXECPREFIX "/usr/libexec/"
#define TIPIDEE_LIBEXECPREFIX "/usr/libexec/"
#define TIPIDEE_SYSCONFPREFIX "/etc/"

#endif
